def generate_tremor(model, length, scaler, n_sequences):
    import numpy as np
    window = 0
    latent_dim = 0
    if length == 10:
        window = 1000
        latent_dim = 2000
    elif length == 5:
        window = 500
        latent_dim = 1000
    elif length == 2:
        window = 200
        latent_dim = 150
    if length == 10 or length == 5 or length == 2:
        generator = model
        generated_sequences = np.zeros((n_sequences, window))
        generated_sequences[:] = np.nan
        for _i_ in range(n_sequences):
            vector = np.random.randn(latent_dim)
            vector = vector.reshape(1, latent_dim)
            seq = generator.predict(vector)
            seq = seq.reshape(1, window)
            prediction = scaler.inverse_transform(seq)
            generated_sequences[_i_] = prediction[0]
        return generated_sequences
    else:
        print("Please specify the proper length of time series to be generated")


from setuptools import setup, find_packages


classifiers = [
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Education',
    'Operating System :: Microsoft :: Windows',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3'
]
setup(
    name='TremorGan',
    author='Anas Ibrahim',
    author_email = 'aibrah43@uwo.ca',
    version='0.0.1',
    description='Generate Tremor data using a Generative Adversarial Network',
    Long_description = open('README.txt').read() + '\n\n' + open('CHANGELOG.txt').read(),
    url = '',
    License='MIT',
    classifiers = classifiers,
    keywords = 'Tremor data generator',
    packages = find_packages(),
    install_requires=['numpy','tensorflow','keras']
)